/*******************************************************************************
* File Name: PWMsinegen.c
* Version 2.10
*
* Description:
*  This file provides the source code to the API for the PWMsinegen
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PWMsinegen.h"

uint8 PWMsinegen_initVar = 0u;


/*******************************************************************************
* Function Name: PWMsinegen_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default PWMsinegen configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (PWMsinegen__QUAD == PWMsinegen_CONFIG)
        PWMsinegen_CONTROL_REG = PWMsinegen_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        PWMsinegen_TRIG_CONTROL1_REG  = PWMsinegen_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        PWMsinegen_SetInterruptMode(PWMsinegen_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        PWMsinegen_SetCounterMode(PWMsinegen_COUNT_DOWN);
        PWMsinegen_WritePeriod(PWMsinegen_QUAD_PERIOD_INIT_VALUE);
        PWMsinegen_WriteCounter(PWMsinegen_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (PWMsinegen__QUAD == PWMsinegen_CONFIG) */

    #if (PWMsinegen__TIMER == PWMsinegen_CONFIG)
        PWMsinegen_CONTROL_REG = PWMsinegen_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        PWMsinegen_TRIG_CONTROL1_REG  = PWMsinegen_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        PWMsinegen_SetInterruptMode(PWMsinegen_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        PWMsinegen_WritePeriod(PWMsinegen_TC_PERIOD_VALUE );

        #if (PWMsinegen__COMPARE == PWMsinegen_TC_COMP_CAP_MODE)
            PWMsinegen_WriteCompare(PWMsinegen_TC_COMPARE_VALUE);

            #if (1u == PWMsinegen_TC_COMPARE_SWAP)
                PWMsinegen_SetCompareSwap(1u);
                PWMsinegen_WriteCompareBuf(PWMsinegen_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == PWMsinegen_TC_COMPARE_SWAP) */
        #endif  /* (PWMsinegen__COMPARE == PWMsinegen_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (PWMsinegen_CY_TCPWM_V2 && PWMsinegen_TIMER_UPDOWN_CNT_USED && !PWMsinegen_CY_TCPWM_4000)
            PWMsinegen_WriteCounter(1u);
        #elif(PWMsinegen__COUNT_DOWN == PWMsinegen_TC_COUNTER_MODE)
            PWMsinegen_WriteCounter(PWMsinegen_TC_PERIOD_VALUE);
        #else
            PWMsinegen_WriteCounter(0u);
        #endif /* (PWMsinegen_CY_TCPWM_V2 && PWMsinegen_TIMER_UPDOWN_CNT_USED && !PWMsinegen_CY_TCPWM_4000) */
    #endif  /* (PWMsinegen__TIMER == PWMsinegen_CONFIG) */

    #if (PWMsinegen__PWM_SEL == PWMsinegen_CONFIG)
        PWMsinegen_CONTROL_REG = PWMsinegen_CTRL_PWM_BASE_CONFIG;

        #if (PWMsinegen__PWM_PR == PWMsinegen_PWM_MODE)
            PWMsinegen_CONTROL_REG |= PWMsinegen_CTRL_PWM_RUN_MODE;
            PWMsinegen_WriteCounter(PWMsinegen_PWM_PR_INIT_VALUE);
        #else
            PWMsinegen_CONTROL_REG |= PWMsinegen_CTRL_PWM_ALIGN | PWMsinegen_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (PWMsinegen_CY_TCPWM_V2 && PWMsinegen_PWM_UPDOWN_CNT_USED && !PWMsinegen_CY_TCPWM_4000)
                PWMsinegen_WriteCounter(1u);
            #elif (PWMsinegen__RIGHT == PWMsinegen_PWM_ALIGN)
                PWMsinegen_WriteCounter(PWMsinegen_PWM_PERIOD_VALUE);
            #else 
                PWMsinegen_WriteCounter(0u);
            #endif  /* (PWMsinegen_CY_TCPWM_V2 && PWMsinegen_PWM_UPDOWN_CNT_USED && !PWMsinegen_CY_TCPWM_4000) */
        #endif  /* (PWMsinegen__PWM_PR == PWMsinegen_PWM_MODE) */

        #if (PWMsinegen__PWM_DT == PWMsinegen_PWM_MODE)
            PWMsinegen_CONTROL_REG |= PWMsinegen_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (PWMsinegen__PWM_DT == PWMsinegen_PWM_MODE) */

        #if (PWMsinegen__PWM == PWMsinegen_PWM_MODE)
            PWMsinegen_CONTROL_REG |= PWMsinegen_CTRL_PWM_PRESCALER;
        #endif  /* (PWMsinegen__PWM == PWMsinegen_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        PWMsinegen_TRIG_CONTROL1_REG  = PWMsinegen_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        PWMsinegen_SetInterruptMode(PWMsinegen_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (PWMsinegen__PWM_PR == PWMsinegen_PWM_MODE)
            PWMsinegen_TRIG_CONTROL2_REG =
                    (PWMsinegen_CC_MATCH_NO_CHANGE    |
                    PWMsinegen_OVERLOW_NO_CHANGE      |
                    PWMsinegen_UNDERFLOW_NO_CHANGE);
        #else
            #if (PWMsinegen__LEFT == PWMsinegen_PWM_ALIGN)
                PWMsinegen_TRIG_CONTROL2_REG = PWMsinegen_PWM_MODE_LEFT;
            #endif  /* ( PWMsinegen_PWM_LEFT == PWMsinegen_PWM_ALIGN) */

            #if (PWMsinegen__RIGHT == PWMsinegen_PWM_ALIGN)
                PWMsinegen_TRIG_CONTROL2_REG = PWMsinegen_PWM_MODE_RIGHT;
            #endif  /* ( PWMsinegen_PWM_RIGHT == PWMsinegen_PWM_ALIGN) */

            #if (PWMsinegen__CENTER == PWMsinegen_PWM_ALIGN)
                PWMsinegen_TRIG_CONTROL2_REG = PWMsinegen_PWM_MODE_CENTER;
            #endif  /* ( PWMsinegen_PWM_CENTER == PWMsinegen_PWM_ALIGN) */

            #if (PWMsinegen__ASYMMETRIC == PWMsinegen_PWM_ALIGN)
                PWMsinegen_TRIG_CONTROL2_REG = PWMsinegen_PWM_MODE_ASYM;
            #endif  /* (PWMsinegen__ASYMMETRIC == PWMsinegen_PWM_ALIGN) */
        #endif  /* (PWMsinegen__PWM_PR == PWMsinegen_PWM_MODE) */

        /* Set other values from customizer */
        PWMsinegen_WritePeriod(PWMsinegen_PWM_PERIOD_VALUE );
        PWMsinegen_WriteCompare(PWMsinegen_PWM_COMPARE_VALUE);

        #if (1u == PWMsinegen_PWM_COMPARE_SWAP)
            PWMsinegen_SetCompareSwap(1u);
            PWMsinegen_WriteCompareBuf(PWMsinegen_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == PWMsinegen_PWM_COMPARE_SWAP) */

        #if (1u == PWMsinegen_PWM_PERIOD_SWAP)
            PWMsinegen_SetPeriodSwap(1u);
            PWMsinegen_WritePeriodBuf(PWMsinegen_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == PWMsinegen_PWM_PERIOD_SWAP) */
    #endif  /* (PWMsinegen__PWM_SEL == PWMsinegen_CONFIG) */
    
}


/*******************************************************************************
* Function Name: PWMsinegen_Enable
********************************************************************************
*
* Summary:
*  Enables the PWMsinegen.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    PWMsinegen_BLOCK_CONTROL_REG |= PWMsinegen_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (PWMsinegen__PWM_SEL == PWMsinegen_CONFIG)
        #if (0u == PWMsinegen_PWM_START_SIGNAL_PRESENT)
            PWMsinegen_TriggerCommand(PWMsinegen_MASK, PWMsinegen_CMD_START);
        #endif /* (0u == PWMsinegen_PWM_START_SIGNAL_PRESENT) */
    #endif /* (PWMsinegen__PWM_SEL == PWMsinegen_CONFIG) */

    #if (PWMsinegen__TIMER == PWMsinegen_CONFIG)
        #if (0u == PWMsinegen_TC_START_SIGNAL_PRESENT)
            PWMsinegen_TriggerCommand(PWMsinegen_MASK, PWMsinegen_CMD_START);
        #endif /* (0u == PWMsinegen_TC_START_SIGNAL_PRESENT) */
    #endif /* (PWMsinegen__TIMER == PWMsinegen_CONFIG) */
    
    #if (PWMsinegen__QUAD == PWMsinegen_CONFIG)
        #if (0u != PWMsinegen_QUAD_AUTO_START)
            PWMsinegen_TriggerCommand(PWMsinegen_MASK, PWMsinegen_CMD_RELOAD);
        #endif /* (0u != PWMsinegen_QUAD_AUTO_START) */
    #endif  /* (PWMsinegen__QUAD == PWMsinegen_CONFIG) */
}


/*******************************************************************************
* Function Name: PWMsinegen_Start
********************************************************************************
*
* Summary:
*  Initializes the PWMsinegen with default customizer
*  values when called the first time and enables the PWMsinegen.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PWMsinegen_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time PWMsinegen_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the PWMsinegen_Start() routine.
*
*******************************************************************************/
void PWMsinegen_Start(void)
{
    if (0u == PWMsinegen_initVar)
    {
        PWMsinegen_Init();
        PWMsinegen_initVar = 1u;
    }

    PWMsinegen_Enable();
}


/*******************************************************************************
* Function Name: PWMsinegen_Stop
********************************************************************************
*
* Summary:
*  Disables the PWMsinegen.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_BLOCK_CONTROL_REG &= (uint32)~PWMsinegen_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the PWMsinegen. This function is used when
*  configured as a generic PWMsinegen and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the PWMsinegen to operate in
*   Values:
*   - PWMsinegen_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - PWMsinegen_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - PWMsinegen_MODE_QUAD - Quadrature decoder
*         - PWMsinegen_MODE_PWM - PWM
*         - PWMsinegen_MODE_PWM_DT - PWM with dead time
*         - PWMsinegen_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_MODE_MASK;
    PWMsinegen_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - PWMsinegen_MODE_X1 - Counts on phi 1 rising
*         - PWMsinegen_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - PWMsinegen_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_QUAD_MODE_MASK;
    PWMsinegen_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - PWMsinegen_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - PWMsinegen_PRESCALE_DIVBY2    - Divide by 2
*         - PWMsinegen_PRESCALE_DIVBY4    - Divide by 4
*         - PWMsinegen_PRESCALE_DIVBY8    - Divide by 8
*         - PWMsinegen_PRESCALE_DIVBY16   - Divide by 16
*         - PWMsinegen_PRESCALE_DIVBY32   - Divide by 32
*         - PWMsinegen_PRESCALE_DIVBY64   - Divide by 64
*         - PWMsinegen_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_PRESCALER_MASK;
    PWMsinegen_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWMsinegen runs
*  continuously or stops when terminal count is reached.  By default the
*  PWMsinegen operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_ONESHOT_MASK;
    PWMsinegen_CONTROL_REG |= ((uint32)((oneShotEnable & PWMsinegen_1BIT_MASK) <<
                                                               PWMsinegen_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetPWMMode(uint32 modeMask)
{
    PWMsinegen_TRIG_CONTROL2_REG = (modeMask & PWMsinegen_6BIT_MASK);
}



/*******************************************************************************
* Function Name: PWMsinegen_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_PWM_SYNC_KILL_MASK;
    PWMsinegen_CONTROL_REG |= ((uint32)((syncKillEnable & PWMsinegen_1BIT_MASK)  <<
                                               PWMsinegen_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_PWM_STOP_KILL_MASK;
    PWMsinegen_CONTROL_REG |= ((uint32)((stopOnKillEnable & PWMsinegen_1BIT_MASK)  <<
                                                         PWMsinegen_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_PRESCALER_MASK;
    PWMsinegen_CONTROL_REG |= ((uint32)((deadTime & PWMsinegen_8BIT_MASK) <<
                                                          PWMsinegen_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - PWMsinegen_INVERT_LINE   - Inverts the line output
*         - PWMsinegen_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_INV_OUT_MASK;
    PWMsinegen_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: PWMsinegen_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_WriteCounter(uint32 count)
{
    PWMsinegen_COUNTER_REG = (count & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 PWMsinegen_ReadCounter(void)
{
    return (PWMsinegen_COUNTER_REG & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - PWMsinegen_COUNT_UP       - Counts up
*     - PWMsinegen_COUNT_DOWN     - Counts down
*     - PWMsinegen_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - PWMsinegen_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_UPDOWN_MASK;
    PWMsinegen_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_WritePeriod(uint32 period)
{
    PWMsinegen_PERIOD_REG = (period & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 PWMsinegen_ReadPeriod(void)
{
    return (PWMsinegen_PERIOD_REG & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_RELOAD_CC_MASK;
    PWMsinegen_CONTROL_REG |= (swapEnable & PWMsinegen_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_WritePeriodBuf(uint32 periodBuf)
{
    PWMsinegen_PERIOD_BUF_REG = (periodBuf & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 PWMsinegen_ReadPeriodBuf(void)
{
    return (PWMsinegen_PERIOD_BUF_REG & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_CONTROL_REG &= (uint32)~PWMsinegen_RELOAD_PERIOD_MASK;
    PWMsinegen_CONTROL_REG |= ((uint32)((swapEnable & PWMsinegen_1BIT_MASK) <<
                                                            PWMsinegen_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void PWMsinegen_WriteCompare(uint32 compare)
{
    #if (PWMsinegen_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (PWMsinegen_CY_TCPWM_4000) */

    #if (PWMsinegen_CY_TCPWM_4000)
        currentMode = ((PWMsinegen_CONTROL_REG & PWMsinegen_UPDOWN_MASK) >> PWMsinegen_UPDOWN_SHIFT);

        if (((uint32)PWMsinegen__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)PWMsinegen__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (PWMsinegen_CY_TCPWM_4000) */
    
    PWMsinegen_COMP_CAP_REG = (compare & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 PWMsinegen_ReadCompare(void)
{
    #if (PWMsinegen_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (PWMsinegen_CY_TCPWM_4000) */

    #if (PWMsinegen_CY_TCPWM_4000)
        currentMode = ((PWMsinegen_CONTROL_REG & PWMsinegen_UPDOWN_MASK) >> PWMsinegen_UPDOWN_SHIFT);
        
        regVal = PWMsinegen_COMP_CAP_REG;
        
        if (((uint32)PWMsinegen__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)PWMsinegen__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & PWMsinegen_16BIT_MASK);
    #else
        return (PWMsinegen_COMP_CAP_REG & PWMsinegen_16BIT_MASK);
    #endif /* (PWMsinegen_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: PWMsinegen_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void PWMsinegen_WriteCompareBuf(uint32 compareBuf)
{
    #if (PWMsinegen_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (PWMsinegen_CY_TCPWM_4000) */

    #if (PWMsinegen_CY_TCPWM_4000)
        currentMode = ((PWMsinegen_CONTROL_REG & PWMsinegen_UPDOWN_MASK) >> PWMsinegen_UPDOWN_SHIFT);

        if (((uint32)PWMsinegen__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)PWMsinegen__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (PWMsinegen_CY_TCPWM_4000) */
    
    PWMsinegen_COMP_CAP_BUF_REG = (compareBuf & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 PWMsinegen_ReadCompareBuf(void)
{
    #if (PWMsinegen_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (PWMsinegen_CY_TCPWM_4000) */

    #if (PWMsinegen_CY_TCPWM_4000)
        currentMode = ((PWMsinegen_CONTROL_REG & PWMsinegen_UPDOWN_MASK) >> PWMsinegen_UPDOWN_SHIFT);

        regVal = PWMsinegen_COMP_CAP_BUF_REG;
        
        if (((uint32)PWMsinegen__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)PWMsinegen__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & PWMsinegen_16BIT_MASK);
    #else
        return (PWMsinegen_COMP_CAP_BUF_REG & PWMsinegen_16BIT_MASK);
    #endif /* (PWMsinegen_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: PWMsinegen_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 PWMsinegen_ReadCapture(void)
{
    return (PWMsinegen_COMP_CAP_REG & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 PWMsinegen_ReadCaptureBuf(void)
{
    return (PWMsinegen_COMP_CAP_BUF_REG & PWMsinegen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWMsinegen_TRIG_LEVEL     - Level
*     - PWMsinegen_TRIG_RISING    - Rising edge
*     - PWMsinegen_TRIG_FALLING   - Falling edge
*     - PWMsinegen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_TRIG_CONTROL1_REG &= (uint32)~PWMsinegen_CAPTURE_MASK;
    PWMsinegen_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWMsinegen_TRIG_LEVEL     - Level
*     - PWMsinegen_TRIG_RISING    - Rising edge
*     - PWMsinegen_TRIG_FALLING   - Falling edge
*     - PWMsinegen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_TRIG_CONTROL1_REG &= (uint32)~PWMsinegen_RELOAD_MASK;
    PWMsinegen_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PWMsinegen_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWMsinegen_TRIG_LEVEL     - Level
*     - PWMsinegen_TRIG_RISING    - Rising edge
*     - PWMsinegen_TRIG_FALLING   - Falling edge
*     - PWMsinegen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_TRIG_CONTROL1_REG &= (uint32)~PWMsinegen_START_MASK;
    PWMsinegen_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PWMsinegen_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWMsinegen_TRIG_LEVEL     - Level
*     - PWMsinegen_TRIG_RISING    - Rising edge
*     - PWMsinegen_TRIG_FALLING   - Falling edge
*     - PWMsinegen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_TRIG_CONTROL1_REG &= (uint32)~PWMsinegen_STOP_MASK;
    PWMsinegen_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PWMsinegen_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PWMsinegen_TRIG_LEVEL     - Level
*     - PWMsinegen_TRIG_RISING    - Rising edge
*     - PWMsinegen_TRIG_FALLING   - Falling edge
*     - PWMsinegen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_TRIG_CONTROL1_REG &= (uint32)~PWMsinegen_COUNT_MASK;
    PWMsinegen_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PWMsinegen_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - PWMsinegen_CMD_CAPTURE    - Trigger Capture/Switch command
*     - PWMsinegen_CMD_RELOAD     - Trigger Reload/Index command
*     - PWMsinegen_CMD_STOP       - Trigger Stop/Kill command
*     - PWMsinegen_CMD_START      - Trigger Start/phiB command
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PWMsinegen_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PWMsinegen_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the PWMsinegen.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - PWMsinegen_STATUS_DOWN    - Set if counting down
*     - PWMsinegen_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 PWMsinegen_ReadStatus(void)
{
    return ((PWMsinegen_STATUS_REG >> PWMsinegen_RUNNING_STATUS_SHIFT) |
            (PWMsinegen_STATUS_REG & PWMsinegen_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: PWMsinegen_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - PWMsinegen_INTR_MASK_TC       - Terminal count mask
*     - PWMsinegen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetInterruptMode(uint32 interruptMask)
{
    PWMsinegen_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: PWMsinegen_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - PWMsinegen_INTR_MASK_TC       - Terminal count mask
*     - PWMsinegen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 PWMsinegen_GetInterruptSourceMasked(void)
{
    return (PWMsinegen_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: PWMsinegen_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - PWMsinegen_INTR_MASK_TC       - Terminal count mask
*     - PWMsinegen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 PWMsinegen_GetInterruptSource(void)
{
    return (PWMsinegen_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: PWMsinegen_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - PWMsinegen_INTR_MASK_TC       - Terminal count mask
*     - PWMsinegen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_ClearInterrupt(uint32 interruptMask)
{
    PWMsinegen_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: PWMsinegen_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - PWMsinegen_INTR_MASK_TC       - Terminal count mask
*     - PWMsinegen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PWMsinegen_SetInterrupt(uint32 interruptMask)
{
    PWMsinegen_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
