/*******************************************************************************
* File Name: PWMsinegen.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the PWMsinegen
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_PWMsinegen_H)
#define CY_TCPWM_PWMsinegen_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} PWMsinegen_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  PWMsinegen_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define PWMsinegen_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define PWMsinegen_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define PWMsinegen_CONFIG                         (7lu)

/* Quad Mode */
/* Parameters */
#define PWMsinegen_QUAD_ENCODING_MODES            (0lu)
#define PWMsinegen_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define PWMsinegen_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define PWMsinegen_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define PWMsinegen_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define PWMsinegen_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define PWMsinegen_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define PWMsinegen_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define PWMsinegen_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define PWMsinegen_TC_RUN_MODE                    (0lu)
#define PWMsinegen_TC_COUNTER_MODE                (0lu)
#define PWMsinegen_TC_COMP_CAP_MODE               (2lu)
#define PWMsinegen_TC_PRESCALER                   (0lu)

/* Signal modes */
#define PWMsinegen_TC_RELOAD_SIGNAL_MODE          (0lu)
#define PWMsinegen_TC_COUNT_SIGNAL_MODE           (3lu)
#define PWMsinegen_TC_START_SIGNAL_MODE           (0lu)
#define PWMsinegen_TC_STOP_SIGNAL_MODE            (0lu)
#define PWMsinegen_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define PWMsinegen_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define PWMsinegen_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define PWMsinegen_TC_START_SIGNAL_PRESENT        (0lu)
#define PWMsinegen_TC_STOP_SIGNAL_PRESENT         (0lu)
#define PWMsinegen_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define PWMsinegen_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define PWMsinegen_PWM_KILL_EVENT                 (0lu)
#define PWMsinegen_PWM_STOP_EVENT                 (0lu)
#define PWMsinegen_PWM_MODE                       (4lu)
#define PWMsinegen_PWM_OUT_N_INVERT               (0lu)
#define PWMsinegen_PWM_OUT_INVERT                 (0lu)
#define PWMsinegen_PWM_ALIGN                      (0lu)
#define PWMsinegen_PWM_RUN_MODE                   (0lu)
#define PWMsinegen_PWM_DEAD_TIME_CYCLE            (0lu)
#define PWMsinegen_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define PWMsinegen_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define PWMsinegen_PWM_COUNT_SIGNAL_MODE          (3lu)
#define PWMsinegen_PWM_START_SIGNAL_MODE          (0lu)
#define PWMsinegen_PWM_STOP_SIGNAL_MODE           (0lu)
#define PWMsinegen_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define PWMsinegen_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define PWMsinegen_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define PWMsinegen_PWM_START_SIGNAL_PRESENT       (0lu)
#define PWMsinegen_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define PWMsinegen_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define PWMsinegen_PWM_INTERRUPT_MASK             (0lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define PWMsinegen_TC_PERIOD_VALUE                (65535lu)
#define PWMsinegen_TC_COMPARE_VALUE               (65535lu)
#define PWMsinegen_TC_COMPARE_BUF_VALUE           (65535lu)
#define PWMsinegen_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define PWMsinegen_PWM_PERIOD_VALUE               (256lu)
#define PWMsinegen_PWM_PERIOD_BUF_VALUE           (65535lu)
#define PWMsinegen_PWM_PERIOD_SWAP                (0lu)
#define PWMsinegen_PWM_COMPARE_VALUE              (127lu)
#define PWMsinegen_PWM_COMPARE_BUF_VALUE          (65535lu)
#define PWMsinegen_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define PWMsinegen__LEFT 0
#define PWMsinegen__RIGHT 1
#define PWMsinegen__CENTER 2
#define PWMsinegen__ASYMMETRIC 3

#define PWMsinegen__X1 0
#define PWMsinegen__X2 1
#define PWMsinegen__X4 2

#define PWMsinegen__PWM 4
#define PWMsinegen__PWM_DT 5
#define PWMsinegen__PWM_PR 6

#define PWMsinegen__INVERSE 1
#define PWMsinegen__DIRECT 0

#define PWMsinegen__CAPTURE 2
#define PWMsinegen__COMPARE 0

#define PWMsinegen__TRIG_LEVEL 3
#define PWMsinegen__TRIG_RISING 0
#define PWMsinegen__TRIG_FALLING 1
#define PWMsinegen__TRIG_BOTH 2

#define PWMsinegen__INTR_MASK_TC 1
#define PWMsinegen__INTR_MASK_CC_MATCH 2
#define PWMsinegen__INTR_MASK_NONE 0
#define PWMsinegen__INTR_MASK_TC_CC 3

#define PWMsinegen__UNCONFIG 8
#define PWMsinegen__TIMER 1
#define PWMsinegen__QUAD 3
#define PWMsinegen__PWM_SEL 7

#define PWMsinegen__COUNT_UP 0
#define PWMsinegen__COUNT_DOWN 1
#define PWMsinegen__COUNT_UPDOWN0 2
#define PWMsinegen__COUNT_UPDOWN1 3


/* Prescaler */
#define PWMsinegen_PRESCALE_DIVBY1                ((uint32)(0u << PWMsinegen_PRESCALER_SHIFT))
#define PWMsinegen_PRESCALE_DIVBY2                ((uint32)(1u << PWMsinegen_PRESCALER_SHIFT))
#define PWMsinegen_PRESCALE_DIVBY4                ((uint32)(2u << PWMsinegen_PRESCALER_SHIFT))
#define PWMsinegen_PRESCALE_DIVBY8                ((uint32)(3u << PWMsinegen_PRESCALER_SHIFT))
#define PWMsinegen_PRESCALE_DIVBY16               ((uint32)(4u << PWMsinegen_PRESCALER_SHIFT))
#define PWMsinegen_PRESCALE_DIVBY32               ((uint32)(5u << PWMsinegen_PRESCALER_SHIFT))
#define PWMsinegen_PRESCALE_DIVBY64               ((uint32)(6u << PWMsinegen_PRESCALER_SHIFT))
#define PWMsinegen_PRESCALE_DIVBY128              ((uint32)(7u << PWMsinegen_PRESCALER_SHIFT))

/* TCPWM set modes */
#define PWMsinegen_MODE_TIMER_COMPARE             ((uint32)(PWMsinegen__COMPARE         <<  \
                                                                  PWMsinegen_MODE_SHIFT))
#define PWMsinegen_MODE_TIMER_CAPTURE             ((uint32)(PWMsinegen__CAPTURE         <<  \
                                                                  PWMsinegen_MODE_SHIFT))
#define PWMsinegen_MODE_QUAD                      ((uint32)(PWMsinegen__QUAD            <<  \
                                                                  PWMsinegen_MODE_SHIFT))
#define PWMsinegen_MODE_PWM                       ((uint32)(PWMsinegen__PWM             <<  \
                                                                  PWMsinegen_MODE_SHIFT))
#define PWMsinegen_MODE_PWM_DT                    ((uint32)(PWMsinegen__PWM_DT          <<  \
                                                                  PWMsinegen_MODE_SHIFT))
#define PWMsinegen_MODE_PWM_PR                    ((uint32)(PWMsinegen__PWM_PR          <<  \
                                                                  PWMsinegen_MODE_SHIFT))

/* Quad Modes */
#define PWMsinegen_MODE_X1                        ((uint32)(PWMsinegen__X1              <<  \
                                                                  PWMsinegen_QUAD_MODE_SHIFT))
#define PWMsinegen_MODE_X2                        ((uint32)(PWMsinegen__X2              <<  \
                                                                  PWMsinegen_QUAD_MODE_SHIFT))
#define PWMsinegen_MODE_X4                        ((uint32)(PWMsinegen__X4              <<  \
                                                                  PWMsinegen_QUAD_MODE_SHIFT))

/* Counter modes */
#define PWMsinegen_COUNT_UP                       ((uint32)(PWMsinegen__COUNT_UP        <<  \
                                                                  PWMsinegen_UPDOWN_SHIFT))
#define PWMsinegen_COUNT_DOWN                     ((uint32)(PWMsinegen__COUNT_DOWN      <<  \
                                                                  PWMsinegen_UPDOWN_SHIFT))
#define PWMsinegen_COUNT_UPDOWN0                  ((uint32)(PWMsinegen__COUNT_UPDOWN0   <<  \
                                                                  PWMsinegen_UPDOWN_SHIFT))
#define PWMsinegen_COUNT_UPDOWN1                  ((uint32)(PWMsinegen__COUNT_UPDOWN1   <<  \
                                                                  PWMsinegen_UPDOWN_SHIFT))

/* PWM output invert */
#define PWMsinegen_INVERT_LINE                    ((uint32)(PWMsinegen__INVERSE         <<  \
                                                                  PWMsinegen_INV_OUT_SHIFT))
#define PWMsinegen_INVERT_LINE_N                  ((uint32)(PWMsinegen__INVERSE         <<  \
                                                                  PWMsinegen_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define PWMsinegen_TRIG_RISING                    ((uint32)PWMsinegen__TRIG_RISING)
#define PWMsinegen_TRIG_FALLING                   ((uint32)PWMsinegen__TRIG_FALLING)
#define PWMsinegen_TRIG_BOTH                      ((uint32)PWMsinegen__TRIG_BOTH)
#define PWMsinegen_TRIG_LEVEL                     ((uint32)PWMsinegen__TRIG_LEVEL)

/* Interrupt mask */
#define PWMsinegen_INTR_MASK_TC                   ((uint32)PWMsinegen__INTR_MASK_TC)
#define PWMsinegen_INTR_MASK_CC_MATCH             ((uint32)PWMsinegen__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define PWMsinegen_CC_MATCH_SET                   (0x00u)
#define PWMsinegen_CC_MATCH_CLEAR                 (0x01u)
#define PWMsinegen_CC_MATCH_INVERT                (0x02u)
#define PWMsinegen_CC_MATCH_NO_CHANGE             (0x03u)
#define PWMsinegen_OVERLOW_SET                    (0x00u)
#define PWMsinegen_OVERLOW_CLEAR                  (0x04u)
#define PWMsinegen_OVERLOW_INVERT                 (0x08u)
#define PWMsinegen_OVERLOW_NO_CHANGE              (0x0Cu)
#define PWMsinegen_UNDERFLOW_SET                  (0x00u)
#define PWMsinegen_UNDERFLOW_CLEAR                (0x10u)
#define PWMsinegen_UNDERFLOW_INVERT               (0x20u)
#define PWMsinegen_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define PWMsinegen_PWM_MODE_LEFT                  (PWMsinegen_CC_MATCH_CLEAR        |   \
                                                         PWMsinegen_OVERLOW_SET           |   \
                                                         PWMsinegen_UNDERFLOW_NO_CHANGE)
#define PWMsinegen_PWM_MODE_RIGHT                 (PWMsinegen_CC_MATCH_SET          |   \
                                                         PWMsinegen_OVERLOW_NO_CHANGE     |   \
                                                         PWMsinegen_UNDERFLOW_CLEAR)
#define PWMsinegen_PWM_MODE_ASYM                  (PWMsinegen_CC_MATCH_INVERT       |   \
                                                         PWMsinegen_OVERLOW_SET           |   \
                                                         PWMsinegen_UNDERFLOW_CLEAR)

#if (PWMsinegen_CY_TCPWM_V2)
    #if(PWMsinegen_CY_TCPWM_4000)
        #define PWMsinegen_PWM_MODE_CENTER                (PWMsinegen_CC_MATCH_INVERT       |   \
                                                                 PWMsinegen_OVERLOW_NO_CHANGE     |   \
                                                                 PWMsinegen_UNDERFLOW_CLEAR)
    #else
        #define PWMsinegen_PWM_MODE_CENTER                (PWMsinegen_CC_MATCH_INVERT       |   \
                                                                 PWMsinegen_OVERLOW_SET           |   \
                                                                 PWMsinegen_UNDERFLOW_CLEAR)
    #endif /* (PWMsinegen_CY_TCPWM_4000) */
#else
    #define PWMsinegen_PWM_MODE_CENTER                (PWMsinegen_CC_MATCH_INVERT       |   \
                                                             PWMsinegen_OVERLOW_NO_CHANGE     |   \
                                                             PWMsinegen_UNDERFLOW_CLEAR)
#endif /* (PWMsinegen_CY_TCPWM_NEW) */

/* Command operations without condition */
#define PWMsinegen_CMD_CAPTURE                    (0u)
#define PWMsinegen_CMD_RELOAD                     (8u)
#define PWMsinegen_CMD_STOP                       (16u)
#define PWMsinegen_CMD_START                      (24u)

/* Status */
#define PWMsinegen_STATUS_DOWN                    (1u)
#define PWMsinegen_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   PWMsinegen_Init(void);
void   PWMsinegen_Enable(void);
void   PWMsinegen_Start(void);
void   PWMsinegen_Stop(void);

void   PWMsinegen_SetMode(uint32 mode);
void   PWMsinegen_SetCounterMode(uint32 counterMode);
void   PWMsinegen_SetPWMMode(uint32 modeMask);
void   PWMsinegen_SetQDMode(uint32 qdMode);

void   PWMsinegen_SetPrescaler(uint32 prescaler);
void   PWMsinegen_TriggerCommand(uint32 mask, uint32 command);
void   PWMsinegen_SetOneShot(uint32 oneShotEnable);
uint32 PWMsinegen_ReadStatus(void);

void   PWMsinegen_SetPWMSyncKill(uint32 syncKillEnable);
void   PWMsinegen_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   PWMsinegen_SetPWMDeadTime(uint32 deadTime);
void   PWMsinegen_SetPWMInvert(uint32 mask);

void   PWMsinegen_SetInterruptMode(uint32 interruptMask);
uint32 PWMsinegen_GetInterruptSourceMasked(void);
uint32 PWMsinegen_GetInterruptSource(void);
void   PWMsinegen_ClearInterrupt(uint32 interruptMask);
void   PWMsinegen_SetInterrupt(uint32 interruptMask);

void   PWMsinegen_WriteCounter(uint32 count);
uint32 PWMsinegen_ReadCounter(void);

uint32 PWMsinegen_ReadCapture(void);
uint32 PWMsinegen_ReadCaptureBuf(void);

void   PWMsinegen_WritePeriod(uint32 period);
uint32 PWMsinegen_ReadPeriod(void);
void   PWMsinegen_WritePeriodBuf(uint32 periodBuf);
uint32 PWMsinegen_ReadPeriodBuf(void);

void   PWMsinegen_WriteCompare(uint32 compare);
uint32 PWMsinegen_ReadCompare(void);
void   PWMsinegen_WriteCompareBuf(uint32 compareBuf);
uint32 PWMsinegen_ReadCompareBuf(void);

void   PWMsinegen_SetPeriodSwap(uint32 swapEnable);
void   PWMsinegen_SetCompareSwap(uint32 swapEnable);

void   PWMsinegen_SetCaptureMode(uint32 triggerMode);
void   PWMsinegen_SetReloadMode(uint32 triggerMode);
void   PWMsinegen_SetStartMode(uint32 triggerMode);
void   PWMsinegen_SetStopMode(uint32 triggerMode);
void   PWMsinegen_SetCountMode(uint32 triggerMode);

void   PWMsinegen_SaveConfig(void);
void   PWMsinegen_RestoreConfig(void);
void   PWMsinegen_Sleep(void);
void   PWMsinegen_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define PWMsinegen_BLOCK_CONTROL_REG              (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define PWMsinegen_BLOCK_CONTROL_PTR              ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define PWMsinegen_COMMAND_REG                    (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define PWMsinegen_COMMAND_PTR                    ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define PWMsinegen_INTRRUPT_CAUSE_REG             (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define PWMsinegen_INTRRUPT_CAUSE_PTR             ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define PWMsinegen_CONTROL_REG                    (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__CTRL )
#define PWMsinegen_CONTROL_PTR                    ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__CTRL )
#define PWMsinegen_STATUS_REG                     (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__STATUS )
#define PWMsinegen_STATUS_PTR                     ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__STATUS )
#define PWMsinegen_COUNTER_REG                    (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__COUNTER )
#define PWMsinegen_COUNTER_PTR                    ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__COUNTER )
#define PWMsinegen_COMP_CAP_REG                   (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__CC )
#define PWMsinegen_COMP_CAP_PTR                   ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__CC )
#define PWMsinegen_COMP_CAP_BUF_REG               (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__CC_BUFF )
#define PWMsinegen_COMP_CAP_BUF_PTR               ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__CC_BUFF )
#define PWMsinegen_PERIOD_REG                     (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__PERIOD )
#define PWMsinegen_PERIOD_PTR                     ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__PERIOD )
#define PWMsinegen_PERIOD_BUF_REG                 (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define PWMsinegen_PERIOD_BUF_PTR                 ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define PWMsinegen_TRIG_CONTROL0_REG              (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define PWMsinegen_TRIG_CONTROL0_PTR              ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define PWMsinegen_TRIG_CONTROL1_REG              (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define PWMsinegen_TRIG_CONTROL1_PTR              ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define PWMsinegen_TRIG_CONTROL2_REG              (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define PWMsinegen_TRIG_CONTROL2_PTR              ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define PWMsinegen_INTERRUPT_REQ_REG              (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__INTR )
#define PWMsinegen_INTERRUPT_REQ_PTR              ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__INTR )
#define PWMsinegen_INTERRUPT_SET_REG              (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__INTR_SET )
#define PWMsinegen_INTERRUPT_SET_PTR              ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__INTR_SET )
#define PWMsinegen_INTERRUPT_MASK_REG             (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__INTR_MASK )
#define PWMsinegen_INTERRUPT_MASK_PTR             ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__INTR_MASK )
#define PWMsinegen_INTERRUPT_MASKED_REG           (*(reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__INTR_MASKED )
#define PWMsinegen_INTERRUPT_MASKED_PTR           ( (reg32 *) PWMsinegen_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define PWMsinegen_MASK                           ((uint32)PWMsinegen_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define PWMsinegen_RELOAD_CC_SHIFT                (0u)
#define PWMsinegen_RELOAD_PERIOD_SHIFT            (1u)
#define PWMsinegen_PWM_SYNC_KILL_SHIFT            (2u)
#define PWMsinegen_PWM_STOP_KILL_SHIFT            (3u)
#define PWMsinegen_PRESCALER_SHIFT                (8u)
#define PWMsinegen_UPDOWN_SHIFT                   (16u)
#define PWMsinegen_ONESHOT_SHIFT                  (18u)
#define PWMsinegen_QUAD_MODE_SHIFT                (20u)
#define PWMsinegen_INV_OUT_SHIFT                  (20u)
#define PWMsinegen_INV_COMPL_OUT_SHIFT            (21u)
#define PWMsinegen_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define PWMsinegen_RELOAD_CC_MASK                 ((uint32)(PWMsinegen_1BIT_MASK        <<  \
                                                                            PWMsinegen_RELOAD_CC_SHIFT))
#define PWMsinegen_RELOAD_PERIOD_MASK             ((uint32)(PWMsinegen_1BIT_MASK        <<  \
                                                                            PWMsinegen_RELOAD_PERIOD_SHIFT))
#define PWMsinegen_PWM_SYNC_KILL_MASK             ((uint32)(PWMsinegen_1BIT_MASK        <<  \
                                                                            PWMsinegen_PWM_SYNC_KILL_SHIFT))
#define PWMsinegen_PWM_STOP_KILL_MASK             ((uint32)(PWMsinegen_1BIT_MASK        <<  \
                                                                            PWMsinegen_PWM_STOP_KILL_SHIFT))
#define PWMsinegen_PRESCALER_MASK                 ((uint32)(PWMsinegen_8BIT_MASK        <<  \
                                                                            PWMsinegen_PRESCALER_SHIFT))
#define PWMsinegen_UPDOWN_MASK                    ((uint32)(PWMsinegen_2BIT_MASK        <<  \
                                                                            PWMsinegen_UPDOWN_SHIFT))
#define PWMsinegen_ONESHOT_MASK                   ((uint32)(PWMsinegen_1BIT_MASK        <<  \
                                                                            PWMsinegen_ONESHOT_SHIFT))
#define PWMsinegen_QUAD_MODE_MASK                 ((uint32)(PWMsinegen_3BIT_MASK        <<  \
                                                                            PWMsinegen_QUAD_MODE_SHIFT))
#define PWMsinegen_INV_OUT_MASK                   ((uint32)(PWMsinegen_2BIT_MASK        <<  \
                                                                            PWMsinegen_INV_OUT_SHIFT))
#define PWMsinegen_MODE_MASK                      ((uint32)(PWMsinegen_3BIT_MASK        <<  \
                                                                            PWMsinegen_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define PWMsinegen_CAPTURE_SHIFT                  (0u)
#define PWMsinegen_COUNT_SHIFT                    (2u)
#define PWMsinegen_RELOAD_SHIFT                   (4u)
#define PWMsinegen_STOP_SHIFT                     (6u)
#define PWMsinegen_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define PWMsinegen_CAPTURE_MASK                   ((uint32)(PWMsinegen_2BIT_MASK        <<  \
                                                                  PWMsinegen_CAPTURE_SHIFT))
#define PWMsinegen_COUNT_MASK                     ((uint32)(PWMsinegen_2BIT_MASK        <<  \
                                                                  PWMsinegen_COUNT_SHIFT))
#define PWMsinegen_RELOAD_MASK                    ((uint32)(PWMsinegen_2BIT_MASK        <<  \
                                                                  PWMsinegen_RELOAD_SHIFT))
#define PWMsinegen_STOP_MASK                      ((uint32)(PWMsinegen_2BIT_MASK        <<  \
                                                                  PWMsinegen_STOP_SHIFT))
#define PWMsinegen_START_MASK                     ((uint32)(PWMsinegen_2BIT_MASK        <<  \
                                                                  PWMsinegen_START_SHIFT))

/* MASK */
#define PWMsinegen_1BIT_MASK                      ((uint32)0x01u)
#define PWMsinegen_2BIT_MASK                      ((uint32)0x03u)
#define PWMsinegen_3BIT_MASK                      ((uint32)0x07u)
#define PWMsinegen_6BIT_MASK                      ((uint32)0x3Fu)
#define PWMsinegen_8BIT_MASK                      ((uint32)0xFFu)
#define PWMsinegen_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define PWMsinegen_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define PWMsinegen_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(PWMsinegen_QUAD_ENCODING_MODES     << PWMsinegen_QUAD_MODE_SHIFT))       |\
         ((uint32)(PWMsinegen_CONFIG                  << PWMsinegen_MODE_SHIFT)))

#define PWMsinegen_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(PWMsinegen_PWM_STOP_EVENT          << PWMsinegen_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(PWMsinegen_PWM_OUT_INVERT          << PWMsinegen_INV_OUT_SHIFT))         |\
         ((uint32)(PWMsinegen_PWM_OUT_N_INVERT        << PWMsinegen_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(PWMsinegen_PWM_MODE                << PWMsinegen_MODE_SHIFT)))

#define PWMsinegen_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(PWMsinegen_PWM_RUN_MODE         << PWMsinegen_ONESHOT_SHIFT))
            
#define PWMsinegen_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(PWMsinegen_PWM_ALIGN            << PWMsinegen_UPDOWN_SHIFT))

#define PWMsinegen_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(PWMsinegen_PWM_KILL_EVENT      << PWMsinegen_PWM_SYNC_KILL_SHIFT))

#define PWMsinegen_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(PWMsinegen_PWM_DEAD_TIME_CYCLE  << PWMsinegen_PRESCALER_SHIFT))

#define PWMsinegen_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(PWMsinegen_PWM_PRESCALER        << PWMsinegen_PRESCALER_SHIFT))

#define PWMsinegen_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(PWMsinegen_TC_PRESCALER            << PWMsinegen_PRESCALER_SHIFT))       |\
         ((uint32)(PWMsinegen_TC_COUNTER_MODE         << PWMsinegen_UPDOWN_SHIFT))          |\
         ((uint32)(PWMsinegen_TC_RUN_MODE             << PWMsinegen_ONESHOT_SHIFT))         |\
         ((uint32)(PWMsinegen_TC_COMP_CAP_MODE        << PWMsinegen_MODE_SHIFT)))
        
#define PWMsinegen_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(PWMsinegen_QUAD_PHIA_SIGNAL_MODE   << PWMsinegen_COUNT_SHIFT))           |\
         ((uint32)(PWMsinegen_QUAD_INDEX_SIGNAL_MODE  << PWMsinegen_RELOAD_SHIFT))          |\
         ((uint32)(PWMsinegen_QUAD_STOP_SIGNAL_MODE   << PWMsinegen_STOP_SHIFT))            |\
         ((uint32)(PWMsinegen_QUAD_PHIB_SIGNAL_MODE   << PWMsinegen_START_SHIFT)))

#define PWMsinegen_PWM_SIGNALS_MODES                                                              \
        (((uint32)(PWMsinegen_PWM_SWITCH_SIGNAL_MODE  << PWMsinegen_CAPTURE_SHIFT))         |\
         ((uint32)(PWMsinegen_PWM_COUNT_SIGNAL_MODE   << PWMsinegen_COUNT_SHIFT))           |\
         ((uint32)(PWMsinegen_PWM_RELOAD_SIGNAL_MODE  << PWMsinegen_RELOAD_SHIFT))          |\
         ((uint32)(PWMsinegen_PWM_STOP_SIGNAL_MODE    << PWMsinegen_STOP_SHIFT))            |\
         ((uint32)(PWMsinegen_PWM_START_SIGNAL_MODE   << PWMsinegen_START_SHIFT)))

#define PWMsinegen_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(PWMsinegen_TC_CAPTURE_SIGNAL_MODE  << PWMsinegen_CAPTURE_SHIFT))         |\
         ((uint32)(PWMsinegen_TC_COUNT_SIGNAL_MODE    << PWMsinegen_COUNT_SHIFT))           |\
         ((uint32)(PWMsinegen_TC_RELOAD_SIGNAL_MODE   << PWMsinegen_RELOAD_SHIFT))          |\
         ((uint32)(PWMsinegen_TC_STOP_SIGNAL_MODE     << PWMsinegen_STOP_SHIFT))            |\
         ((uint32)(PWMsinegen_TC_START_SIGNAL_MODE    << PWMsinegen_START_SHIFT)))
        
#define PWMsinegen_TIMER_UPDOWN_CNT_USED                                                          \
                ((PWMsinegen__COUNT_UPDOWN0 == PWMsinegen_TC_COUNTER_MODE)                  ||\
                 (PWMsinegen__COUNT_UPDOWN1 == PWMsinegen_TC_COUNTER_MODE))

#define PWMsinegen_PWM_UPDOWN_CNT_USED                                                            \
                ((PWMsinegen__CENTER == PWMsinegen_PWM_ALIGN)                               ||\
                 (PWMsinegen__ASYMMETRIC == PWMsinegen_PWM_ALIGN))               
        
#define PWMsinegen_PWM_PR_INIT_VALUE              (1u)
#define PWMsinegen_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_PWMsinegen_H */

/* [] END OF FILE */
