/*******************************************************************************
* File Name: TimerTick.c
* Version 2.10
*
* Description:
*  This file provides the source code to the API for the TimerTick
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TimerTick.h"

uint8 TimerTick_initVar = 0u;


/*******************************************************************************
* Function Name: TimerTick_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default TimerTick configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (TimerTick__QUAD == TimerTick_CONFIG)
        TimerTick_CONTROL_REG = TimerTick_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        TimerTick_TRIG_CONTROL1_REG  = TimerTick_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        TimerTick_SetInterruptMode(TimerTick_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        TimerTick_SetCounterMode(TimerTick_COUNT_DOWN);
        TimerTick_WritePeriod(TimerTick_QUAD_PERIOD_INIT_VALUE);
        TimerTick_WriteCounter(TimerTick_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (TimerTick__QUAD == TimerTick_CONFIG) */

    #if (TimerTick__TIMER == TimerTick_CONFIG)
        TimerTick_CONTROL_REG = TimerTick_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        TimerTick_TRIG_CONTROL1_REG  = TimerTick_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        TimerTick_SetInterruptMode(TimerTick_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        TimerTick_WritePeriod(TimerTick_TC_PERIOD_VALUE );

        #if (TimerTick__COMPARE == TimerTick_TC_COMP_CAP_MODE)
            TimerTick_WriteCompare(TimerTick_TC_COMPARE_VALUE);

            #if (1u == TimerTick_TC_COMPARE_SWAP)
                TimerTick_SetCompareSwap(1u);
                TimerTick_WriteCompareBuf(TimerTick_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == TimerTick_TC_COMPARE_SWAP) */
        #endif  /* (TimerTick__COMPARE == TimerTick_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (TimerTick_CY_TCPWM_V2 && TimerTick_TIMER_UPDOWN_CNT_USED && !TimerTick_CY_TCPWM_4000)
            TimerTick_WriteCounter(1u);
        #elif(TimerTick__COUNT_DOWN == TimerTick_TC_COUNTER_MODE)
            TimerTick_WriteCounter(TimerTick_TC_PERIOD_VALUE);
        #else
            TimerTick_WriteCounter(0u);
        #endif /* (TimerTick_CY_TCPWM_V2 && TimerTick_TIMER_UPDOWN_CNT_USED && !TimerTick_CY_TCPWM_4000) */
    #endif  /* (TimerTick__TIMER == TimerTick_CONFIG) */

    #if (TimerTick__PWM_SEL == TimerTick_CONFIG)
        TimerTick_CONTROL_REG = TimerTick_CTRL_PWM_BASE_CONFIG;

        #if (TimerTick__PWM_PR == TimerTick_PWM_MODE)
            TimerTick_CONTROL_REG |= TimerTick_CTRL_PWM_RUN_MODE;
            TimerTick_WriteCounter(TimerTick_PWM_PR_INIT_VALUE);
        #else
            TimerTick_CONTROL_REG |= TimerTick_CTRL_PWM_ALIGN | TimerTick_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (TimerTick_CY_TCPWM_V2 && TimerTick_PWM_UPDOWN_CNT_USED && !TimerTick_CY_TCPWM_4000)
                TimerTick_WriteCounter(1u);
            #elif (TimerTick__RIGHT == TimerTick_PWM_ALIGN)
                TimerTick_WriteCounter(TimerTick_PWM_PERIOD_VALUE);
            #else 
                TimerTick_WriteCounter(0u);
            #endif  /* (TimerTick_CY_TCPWM_V2 && TimerTick_PWM_UPDOWN_CNT_USED && !TimerTick_CY_TCPWM_4000) */
        #endif  /* (TimerTick__PWM_PR == TimerTick_PWM_MODE) */

        #if (TimerTick__PWM_DT == TimerTick_PWM_MODE)
            TimerTick_CONTROL_REG |= TimerTick_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (TimerTick__PWM_DT == TimerTick_PWM_MODE) */

        #if (TimerTick__PWM == TimerTick_PWM_MODE)
            TimerTick_CONTROL_REG |= TimerTick_CTRL_PWM_PRESCALER;
        #endif  /* (TimerTick__PWM == TimerTick_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        TimerTick_TRIG_CONTROL1_REG  = TimerTick_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        TimerTick_SetInterruptMode(TimerTick_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (TimerTick__PWM_PR == TimerTick_PWM_MODE)
            TimerTick_TRIG_CONTROL2_REG =
                    (TimerTick_CC_MATCH_NO_CHANGE    |
                    TimerTick_OVERLOW_NO_CHANGE      |
                    TimerTick_UNDERFLOW_NO_CHANGE);
        #else
            #if (TimerTick__LEFT == TimerTick_PWM_ALIGN)
                TimerTick_TRIG_CONTROL2_REG = TimerTick_PWM_MODE_LEFT;
            #endif  /* ( TimerTick_PWM_LEFT == TimerTick_PWM_ALIGN) */

            #if (TimerTick__RIGHT == TimerTick_PWM_ALIGN)
                TimerTick_TRIG_CONTROL2_REG = TimerTick_PWM_MODE_RIGHT;
            #endif  /* ( TimerTick_PWM_RIGHT == TimerTick_PWM_ALIGN) */

            #if (TimerTick__CENTER == TimerTick_PWM_ALIGN)
                TimerTick_TRIG_CONTROL2_REG = TimerTick_PWM_MODE_CENTER;
            #endif  /* ( TimerTick_PWM_CENTER == TimerTick_PWM_ALIGN) */

            #if (TimerTick__ASYMMETRIC == TimerTick_PWM_ALIGN)
                TimerTick_TRIG_CONTROL2_REG = TimerTick_PWM_MODE_ASYM;
            #endif  /* (TimerTick__ASYMMETRIC == TimerTick_PWM_ALIGN) */
        #endif  /* (TimerTick__PWM_PR == TimerTick_PWM_MODE) */

        /* Set other values from customizer */
        TimerTick_WritePeriod(TimerTick_PWM_PERIOD_VALUE );
        TimerTick_WriteCompare(TimerTick_PWM_COMPARE_VALUE);

        #if (1u == TimerTick_PWM_COMPARE_SWAP)
            TimerTick_SetCompareSwap(1u);
            TimerTick_WriteCompareBuf(TimerTick_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == TimerTick_PWM_COMPARE_SWAP) */

        #if (1u == TimerTick_PWM_PERIOD_SWAP)
            TimerTick_SetPeriodSwap(1u);
            TimerTick_WritePeriodBuf(TimerTick_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == TimerTick_PWM_PERIOD_SWAP) */
    #endif  /* (TimerTick__PWM_SEL == TimerTick_CONFIG) */
    
}


/*******************************************************************************
* Function Name: TimerTick_Enable
********************************************************************************
*
* Summary:
*  Enables the TimerTick.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    TimerTick_BLOCK_CONTROL_REG |= TimerTick_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (TimerTick__PWM_SEL == TimerTick_CONFIG)
        #if (0u == TimerTick_PWM_START_SIGNAL_PRESENT)
            TimerTick_TriggerCommand(TimerTick_MASK, TimerTick_CMD_START);
        #endif /* (0u == TimerTick_PWM_START_SIGNAL_PRESENT) */
    #endif /* (TimerTick__PWM_SEL == TimerTick_CONFIG) */

    #if (TimerTick__TIMER == TimerTick_CONFIG)
        #if (0u == TimerTick_TC_START_SIGNAL_PRESENT)
            TimerTick_TriggerCommand(TimerTick_MASK, TimerTick_CMD_START);
        #endif /* (0u == TimerTick_TC_START_SIGNAL_PRESENT) */
    #endif /* (TimerTick__TIMER == TimerTick_CONFIG) */
    
    #if (TimerTick__QUAD == TimerTick_CONFIG)
        #if (0u != TimerTick_QUAD_AUTO_START)
            TimerTick_TriggerCommand(TimerTick_MASK, TimerTick_CMD_RELOAD);
        #endif /* (0u != TimerTick_QUAD_AUTO_START) */
    #endif  /* (TimerTick__QUAD == TimerTick_CONFIG) */
}


/*******************************************************************************
* Function Name: TimerTick_Start
********************************************************************************
*
* Summary:
*  Initializes the TimerTick with default customizer
*  values when called the first time and enables the TimerTick.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  TimerTick_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time TimerTick_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the TimerTick_Start() routine.
*
*******************************************************************************/
void TimerTick_Start(void)
{
    if (0u == TimerTick_initVar)
    {
        TimerTick_Init();
        TimerTick_initVar = 1u;
    }

    TimerTick_Enable();
}


/*******************************************************************************
* Function Name: TimerTick_Stop
********************************************************************************
*
* Summary:
*  Disables the TimerTick.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_BLOCK_CONTROL_REG &= (uint32)~TimerTick_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the TimerTick. This function is used when
*  configured as a generic TimerTick and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the TimerTick to operate in
*   Values:
*   - TimerTick_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - TimerTick_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - TimerTick_MODE_QUAD - Quadrature decoder
*         - TimerTick_MODE_PWM - PWM
*         - TimerTick_MODE_PWM_DT - PWM with dead time
*         - TimerTick_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_MODE_MASK;
    TimerTick_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - TimerTick_MODE_X1 - Counts on phi 1 rising
*         - TimerTick_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - TimerTick_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_QUAD_MODE_MASK;
    TimerTick_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - TimerTick_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - TimerTick_PRESCALE_DIVBY2    - Divide by 2
*         - TimerTick_PRESCALE_DIVBY4    - Divide by 4
*         - TimerTick_PRESCALE_DIVBY8    - Divide by 8
*         - TimerTick_PRESCALE_DIVBY16   - Divide by 16
*         - TimerTick_PRESCALE_DIVBY32   - Divide by 32
*         - TimerTick_PRESCALE_DIVBY64   - Divide by 64
*         - TimerTick_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_PRESCALER_MASK;
    TimerTick_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the TimerTick runs
*  continuously or stops when terminal count is reached.  By default the
*  TimerTick operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_ONESHOT_MASK;
    TimerTick_CONTROL_REG |= ((uint32)((oneShotEnable & TimerTick_1BIT_MASK) <<
                                                               TimerTick_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetPWMMode(uint32 modeMask)
{
    TimerTick_TRIG_CONTROL2_REG = (modeMask & TimerTick_6BIT_MASK);
}



/*******************************************************************************
* Function Name: TimerTick_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_PWM_SYNC_KILL_MASK;
    TimerTick_CONTROL_REG |= ((uint32)((syncKillEnable & TimerTick_1BIT_MASK)  <<
                                               TimerTick_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_PWM_STOP_KILL_MASK;
    TimerTick_CONTROL_REG |= ((uint32)((stopOnKillEnable & TimerTick_1BIT_MASK)  <<
                                                         TimerTick_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_PRESCALER_MASK;
    TimerTick_CONTROL_REG |= ((uint32)((deadTime & TimerTick_8BIT_MASK) <<
                                                          TimerTick_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - TimerTick_INVERT_LINE   - Inverts the line output
*         - TimerTick_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_INV_OUT_MASK;
    TimerTick_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: TimerTick_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_WriteCounter(uint32 count)
{
    TimerTick_COUNTER_REG = (count & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 TimerTick_ReadCounter(void)
{
    return (TimerTick_COUNTER_REG & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - TimerTick_COUNT_UP       - Counts up
*     - TimerTick_COUNT_DOWN     - Counts down
*     - TimerTick_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - TimerTick_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_UPDOWN_MASK;
    TimerTick_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_WritePeriod(uint32 period)
{
    TimerTick_PERIOD_REG = (period & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 TimerTick_ReadPeriod(void)
{
    return (TimerTick_PERIOD_REG & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_RELOAD_CC_MASK;
    TimerTick_CONTROL_REG |= (swapEnable & TimerTick_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_WritePeriodBuf(uint32 periodBuf)
{
    TimerTick_PERIOD_BUF_REG = (periodBuf & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 TimerTick_ReadPeriodBuf(void)
{
    return (TimerTick_PERIOD_BUF_REG & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_CONTROL_REG &= (uint32)~TimerTick_RELOAD_PERIOD_MASK;
    TimerTick_CONTROL_REG |= ((uint32)((swapEnable & TimerTick_1BIT_MASK) <<
                                                            TimerTick_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void TimerTick_WriteCompare(uint32 compare)
{
    #if (TimerTick_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (TimerTick_CY_TCPWM_4000) */

    #if (TimerTick_CY_TCPWM_4000)
        currentMode = ((TimerTick_CONTROL_REG & TimerTick_UPDOWN_MASK) >> TimerTick_UPDOWN_SHIFT);

        if (((uint32)TimerTick__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)TimerTick__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (TimerTick_CY_TCPWM_4000) */
    
    TimerTick_COMP_CAP_REG = (compare & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 TimerTick_ReadCompare(void)
{
    #if (TimerTick_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (TimerTick_CY_TCPWM_4000) */

    #if (TimerTick_CY_TCPWM_4000)
        currentMode = ((TimerTick_CONTROL_REG & TimerTick_UPDOWN_MASK) >> TimerTick_UPDOWN_SHIFT);
        
        regVal = TimerTick_COMP_CAP_REG;
        
        if (((uint32)TimerTick__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)TimerTick__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & TimerTick_16BIT_MASK);
    #else
        return (TimerTick_COMP_CAP_REG & TimerTick_16BIT_MASK);
    #endif /* (TimerTick_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: TimerTick_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void TimerTick_WriteCompareBuf(uint32 compareBuf)
{
    #if (TimerTick_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (TimerTick_CY_TCPWM_4000) */

    #if (TimerTick_CY_TCPWM_4000)
        currentMode = ((TimerTick_CONTROL_REG & TimerTick_UPDOWN_MASK) >> TimerTick_UPDOWN_SHIFT);

        if (((uint32)TimerTick__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)TimerTick__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (TimerTick_CY_TCPWM_4000) */
    
    TimerTick_COMP_CAP_BUF_REG = (compareBuf & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 TimerTick_ReadCompareBuf(void)
{
    #if (TimerTick_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (TimerTick_CY_TCPWM_4000) */

    #if (TimerTick_CY_TCPWM_4000)
        currentMode = ((TimerTick_CONTROL_REG & TimerTick_UPDOWN_MASK) >> TimerTick_UPDOWN_SHIFT);

        regVal = TimerTick_COMP_CAP_BUF_REG;
        
        if (((uint32)TimerTick__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)TimerTick__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & TimerTick_16BIT_MASK);
    #else
        return (TimerTick_COMP_CAP_BUF_REG & TimerTick_16BIT_MASK);
    #endif /* (TimerTick_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: TimerTick_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 TimerTick_ReadCapture(void)
{
    return (TimerTick_COMP_CAP_REG & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 TimerTick_ReadCaptureBuf(void)
{
    return (TimerTick_COMP_CAP_BUF_REG & TimerTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerTick_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerTick_TRIG_LEVEL     - Level
*     - TimerTick_TRIG_RISING    - Rising edge
*     - TimerTick_TRIG_FALLING   - Falling edge
*     - TimerTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_TRIG_CONTROL1_REG &= (uint32)~TimerTick_CAPTURE_MASK;
    TimerTick_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerTick_TRIG_LEVEL     - Level
*     - TimerTick_TRIG_RISING    - Rising edge
*     - TimerTick_TRIG_FALLING   - Falling edge
*     - TimerTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_TRIG_CONTROL1_REG &= (uint32)~TimerTick_RELOAD_MASK;
    TimerTick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << TimerTick_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerTick_TRIG_LEVEL     - Level
*     - TimerTick_TRIG_RISING    - Rising edge
*     - TimerTick_TRIG_FALLING   - Falling edge
*     - TimerTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_TRIG_CONTROL1_REG &= (uint32)~TimerTick_START_MASK;
    TimerTick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << TimerTick_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerTick_TRIG_LEVEL     - Level
*     - TimerTick_TRIG_RISING    - Rising edge
*     - TimerTick_TRIG_FALLING   - Falling edge
*     - TimerTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_TRIG_CONTROL1_REG &= (uint32)~TimerTick_STOP_MASK;
    TimerTick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << TimerTick_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerTick_TRIG_LEVEL     - Level
*     - TimerTick_TRIG_RISING    - Rising edge
*     - TimerTick_TRIG_FALLING   - Falling edge
*     - TimerTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_TRIG_CONTROL1_REG &= (uint32)~TimerTick_COUNT_MASK;
    TimerTick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << TimerTick_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - TimerTick_CMD_CAPTURE    - Trigger Capture/Switch command
*     - TimerTick_CMD_RELOAD     - Trigger Reload/Index command
*     - TimerTick_CMD_STOP       - Trigger Stop/Kill command
*     - TimerTick_CMD_START      - Trigger Start/phiB command
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerTick_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerTick_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the TimerTick.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - TimerTick_STATUS_DOWN    - Set if counting down
*     - TimerTick_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 TimerTick_ReadStatus(void)
{
    return ((TimerTick_STATUS_REG >> TimerTick_RUNNING_STATUS_SHIFT) |
            (TimerTick_STATUS_REG & TimerTick_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: TimerTick_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - TimerTick_INTR_MASK_TC       - Terminal count mask
*     - TimerTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetInterruptMode(uint32 interruptMask)
{
    TimerTick_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: TimerTick_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - TimerTick_INTR_MASK_TC       - Terminal count mask
*     - TimerTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 TimerTick_GetInterruptSourceMasked(void)
{
    return (TimerTick_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: TimerTick_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - TimerTick_INTR_MASK_TC       - Terminal count mask
*     - TimerTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 TimerTick_GetInterruptSource(void)
{
    return (TimerTick_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: TimerTick_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - TimerTick_INTR_MASK_TC       - Terminal count mask
*     - TimerTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_ClearInterrupt(uint32 interruptMask)
{
    TimerTick_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: TimerTick_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - TimerTick_INTR_MASK_TC       - Terminal count mask
*     - TimerTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SetInterrupt(uint32 interruptMask)
{
    TimerTick_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
