/*******************************************************************************
* File Name: TimerTick.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the TimerTick
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_TimerTick_H)
#define CY_TCPWM_TimerTick_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} TimerTick_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  TimerTick_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define TimerTick_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define TimerTick_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define TimerTick_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define TimerTick_QUAD_ENCODING_MODES            (0lu)
#define TimerTick_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define TimerTick_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define TimerTick_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define TimerTick_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define TimerTick_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define TimerTick_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define TimerTick_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define TimerTick_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define TimerTick_TC_RUN_MODE                    (0lu)
#define TimerTick_TC_COUNTER_MODE                (0lu)
#define TimerTick_TC_COMP_CAP_MODE               (2lu)
#define TimerTick_TC_PRESCALER                   (0lu)

/* Signal modes */
#define TimerTick_TC_RELOAD_SIGNAL_MODE          (0lu)
#define TimerTick_TC_COUNT_SIGNAL_MODE           (3lu)
#define TimerTick_TC_START_SIGNAL_MODE           (0lu)
#define TimerTick_TC_STOP_SIGNAL_MODE            (0lu)
#define TimerTick_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define TimerTick_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define TimerTick_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define TimerTick_TC_START_SIGNAL_PRESENT        (0lu)
#define TimerTick_TC_STOP_SIGNAL_PRESENT         (0lu)
#define TimerTick_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define TimerTick_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define TimerTick_PWM_KILL_EVENT                 (0lu)
#define TimerTick_PWM_STOP_EVENT                 (0lu)
#define TimerTick_PWM_MODE                       (4lu)
#define TimerTick_PWM_OUT_N_INVERT               (0lu)
#define TimerTick_PWM_OUT_INVERT                 (0lu)
#define TimerTick_PWM_ALIGN                      (0lu)
#define TimerTick_PWM_RUN_MODE                   (0lu)
#define TimerTick_PWM_DEAD_TIME_CYCLE            (0lu)
#define TimerTick_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define TimerTick_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define TimerTick_PWM_COUNT_SIGNAL_MODE          (3lu)
#define TimerTick_PWM_START_SIGNAL_MODE          (0lu)
#define TimerTick_PWM_STOP_SIGNAL_MODE           (0lu)
#define TimerTick_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define TimerTick_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define TimerTick_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define TimerTick_PWM_START_SIGNAL_PRESENT       (0lu)
#define TimerTick_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define TimerTick_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define TimerTick_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define TimerTick_TC_PERIOD_VALUE                (12000lu)
#define TimerTick_TC_COMPARE_VALUE               (65535lu)
#define TimerTick_TC_COMPARE_BUF_VALUE           (65535lu)
#define TimerTick_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define TimerTick_PWM_PERIOD_VALUE               (65535lu)
#define TimerTick_PWM_PERIOD_BUF_VALUE           (65535lu)
#define TimerTick_PWM_PERIOD_SWAP                (0lu)
#define TimerTick_PWM_COMPARE_VALUE              (65535lu)
#define TimerTick_PWM_COMPARE_BUF_VALUE          (65535lu)
#define TimerTick_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define TimerTick__LEFT 0
#define TimerTick__RIGHT 1
#define TimerTick__CENTER 2
#define TimerTick__ASYMMETRIC 3

#define TimerTick__X1 0
#define TimerTick__X2 1
#define TimerTick__X4 2

#define TimerTick__PWM 4
#define TimerTick__PWM_DT 5
#define TimerTick__PWM_PR 6

#define TimerTick__INVERSE 1
#define TimerTick__DIRECT 0

#define TimerTick__CAPTURE 2
#define TimerTick__COMPARE 0

#define TimerTick__TRIG_LEVEL 3
#define TimerTick__TRIG_RISING 0
#define TimerTick__TRIG_FALLING 1
#define TimerTick__TRIG_BOTH 2

#define TimerTick__INTR_MASK_TC 1
#define TimerTick__INTR_MASK_CC_MATCH 2
#define TimerTick__INTR_MASK_NONE 0
#define TimerTick__INTR_MASK_TC_CC 3

#define TimerTick__UNCONFIG 8
#define TimerTick__TIMER 1
#define TimerTick__QUAD 3
#define TimerTick__PWM_SEL 7

#define TimerTick__COUNT_UP 0
#define TimerTick__COUNT_DOWN 1
#define TimerTick__COUNT_UPDOWN0 2
#define TimerTick__COUNT_UPDOWN1 3


/* Prescaler */
#define TimerTick_PRESCALE_DIVBY1                ((uint32)(0u << TimerTick_PRESCALER_SHIFT))
#define TimerTick_PRESCALE_DIVBY2                ((uint32)(1u << TimerTick_PRESCALER_SHIFT))
#define TimerTick_PRESCALE_DIVBY4                ((uint32)(2u << TimerTick_PRESCALER_SHIFT))
#define TimerTick_PRESCALE_DIVBY8                ((uint32)(3u << TimerTick_PRESCALER_SHIFT))
#define TimerTick_PRESCALE_DIVBY16               ((uint32)(4u << TimerTick_PRESCALER_SHIFT))
#define TimerTick_PRESCALE_DIVBY32               ((uint32)(5u << TimerTick_PRESCALER_SHIFT))
#define TimerTick_PRESCALE_DIVBY64               ((uint32)(6u << TimerTick_PRESCALER_SHIFT))
#define TimerTick_PRESCALE_DIVBY128              ((uint32)(7u << TimerTick_PRESCALER_SHIFT))

/* TCPWM set modes */
#define TimerTick_MODE_TIMER_COMPARE             ((uint32)(TimerTick__COMPARE         <<  \
                                                                  TimerTick_MODE_SHIFT))
#define TimerTick_MODE_TIMER_CAPTURE             ((uint32)(TimerTick__CAPTURE         <<  \
                                                                  TimerTick_MODE_SHIFT))
#define TimerTick_MODE_QUAD                      ((uint32)(TimerTick__QUAD            <<  \
                                                                  TimerTick_MODE_SHIFT))
#define TimerTick_MODE_PWM                       ((uint32)(TimerTick__PWM             <<  \
                                                                  TimerTick_MODE_SHIFT))
#define TimerTick_MODE_PWM_DT                    ((uint32)(TimerTick__PWM_DT          <<  \
                                                                  TimerTick_MODE_SHIFT))
#define TimerTick_MODE_PWM_PR                    ((uint32)(TimerTick__PWM_PR          <<  \
                                                                  TimerTick_MODE_SHIFT))

/* Quad Modes */
#define TimerTick_MODE_X1                        ((uint32)(TimerTick__X1              <<  \
                                                                  TimerTick_QUAD_MODE_SHIFT))
#define TimerTick_MODE_X2                        ((uint32)(TimerTick__X2              <<  \
                                                                  TimerTick_QUAD_MODE_SHIFT))
#define TimerTick_MODE_X4                        ((uint32)(TimerTick__X4              <<  \
                                                                  TimerTick_QUAD_MODE_SHIFT))

/* Counter modes */
#define TimerTick_COUNT_UP                       ((uint32)(TimerTick__COUNT_UP        <<  \
                                                                  TimerTick_UPDOWN_SHIFT))
#define TimerTick_COUNT_DOWN                     ((uint32)(TimerTick__COUNT_DOWN      <<  \
                                                                  TimerTick_UPDOWN_SHIFT))
#define TimerTick_COUNT_UPDOWN0                  ((uint32)(TimerTick__COUNT_UPDOWN0   <<  \
                                                                  TimerTick_UPDOWN_SHIFT))
#define TimerTick_COUNT_UPDOWN1                  ((uint32)(TimerTick__COUNT_UPDOWN1   <<  \
                                                                  TimerTick_UPDOWN_SHIFT))

/* PWM output invert */
#define TimerTick_INVERT_LINE                    ((uint32)(TimerTick__INVERSE         <<  \
                                                                  TimerTick_INV_OUT_SHIFT))
#define TimerTick_INVERT_LINE_N                  ((uint32)(TimerTick__INVERSE         <<  \
                                                                  TimerTick_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define TimerTick_TRIG_RISING                    ((uint32)TimerTick__TRIG_RISING)
#define TimerTick_TRIG_FALLING                   ((uint32)TimerTick__TRIG_FALLING)
#define TimerTick_TRIG_BOTH                      ((uint32)TimerTick__TRIG_BOTH)
#define TimerTick_TRIG_LEVEL                     ((uint32)TimerTick__TRIG_LEVEL)

/* Interrupt mask */
#define TimerTick_INTR_MASK_TC                   ((uint32)TimerTick__INTR_MASK_TC)
#define TimerTick_INTR_MASK_CC_MATCH             ((uint32)TimerTick__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define TimerTick_CC_MATCH_SET                   (0x00u)
#define TimerTick_CC_MATCH_CLEAR                 (0x01u)
#define TimerTick_CC_MATCH_INVERT                (0x02u)
#define TimerTick_CC_MATCH_NO_CHANGE             (0x03u)
#define TimerTick_OVERLOW_SET                    (0x00u)
#define TimerTick_OVERLOW_CLEAR                  (0x04u)
#define TimerTick_OVERLOW_INVERT                 (0x08u)
#define TimerTick_OVERLOW_NO_CHANGE              (0x0Cu)
#define TimerTick_UNDERFLOW_SET                  (0x00u)
#define TimerTick_UNDERFLOW_CLEAR                (0x10u)
#define TimerTick_UNDERFLOW_INVERT               (0x20u)
#define TimerTick_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define TimerTick_PWM_MODE_LEFT                  (TimerTick_CC_MATCH_CLEAR        |   \
                                                         TimerTick_OVERLOW_SET           |   \
                                                         TimerTick_UNDERFLOW_NO_CHANGE)
#define TimerTick_PWM_MODE_RIGHT                 (TimerTick_CC_MATCH_SET          |   \
                                                         TimerTick_OVERLOW_NO_CHANGE     |   \
                                                         TimerTick_UNDERFLOW_CLEAR)
#define TimerTick_PWM_MODE_ASYM                  (TimerTick_CC_MATCH_INVERT       |   \
                                                         TimerTick_OVERLOW_SET           |   \
                                                         TimerTick_UNDERFLOW_CLEAR)

#if (TimerTick_CY_TCPWM_V2)
    #if(TimerTick_CY_TCPWM_4000)
        #define TimerTick_PWM_MODE_CENTER                (TimerTick_CC_MATCH_INVERT       |   \
                                                                 TimerTick_OVERLOW_NO_CHANGE     |   \
                                                                 TimerTick_UNDERFLOW_CLEAR)
    #else
        #define TimerTick_PWM_MODE_CENTER                (TimerTick_CC_MATCH_INVERT       |   \
                                                                 TimerTick_OVERLOW_SET           |   \
                                                                 TimerTick_UNDERFLOW_CLEAR)
    #endif /* (TimerTick_CY_TCPWM_4000) */
#else
    #define TimerTick_PWM_MODE_CENTER                (TimerTick_CC_MATCH_INVERT       |   \
                                                             TimerTick_OVERLOW_NO_CHANGE     |   \
                                                             TimerTick_UNDERFLOW_CLEAR)
#endif /* (TimerTick_CY_TCPWM_NEW) */

/* Command operations without condition */
#define TimerTick_CMD_CAPTURE                    (0u)
#define TimerTick_CMD_RELOAD                     (8u)
#define TimerTick_CMD_STOP                       (16u)
#define TimerTick_CMD_START                      (24u)

/* Status */
#define TimerTick_STATUS_DOWN                    (1u)
#define TimerTick_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   TimerTick_Init(void);
void   TimerTick_Enable(void);
void   TimerTick_Start(void);
void   TimerTick_Stop(void);

void   TimerTick_SetMode(uint32 mode);
void   TimerTick_SetCounterMode(uint32 counterMode);
void   TimerTick_SetPWMMode(uint32 modeMask);
void   TimerTick_SetQDMode(uint32 qdMode);

void   TimerTick_SetPrescaler(uint32 prescaler);
void   TimerTick_TriggerCommand(uint32 mask, uint32 command);
void   TimerTick_SetOneShot(uint32 oneShotEnable);
uint32 TimerTick_ReadStatus(void);

void   TimerTick_SetPWMSyncKill(uint32 syncKillEnable);
void   TimerTick_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   TimerTick_SetPWMDeadTime(uint32 deadTime);
void   TimerTick_SetPWMInvert(uint32 mask);

void   TimerTick_SetInterruptMode(uint32 interruptMask);
uint32 TimerTick_GetInterruptSourceMasked(void);
uint32 TimerTick_GetInterruptSource(void);
void   TimerTick_ClearInterrupt(uint32 interruptMask);
void   TimerTick_SetInterrupt(uint32 interruptMask);

void   TimerTick_WriteCounter(uint32 count);
uint32 TimerTick_ReadCounter(void);

uint32 TimerTick_ReadCapture(void);
uint32 TimerTick_ReadCaptureBuf(void);

void   TimerTick_WritePeriod(uint32 period);
uint32 TimerTick_ReadPeriod(void);
void   TimerTick_WritePeriodBuf(uint32 periodBuf);
uint32 TimerTick_ReadPeriodBuf(void);

void   TimerTick_WriteCompare(uint32 compare);
uint32 TimerTick_ReadCompare(void);
void   TimerTick_WriteCompareBuf(uint32 compareBuf);
uint32 TimerTick_ReadCompareBuf(void);

void   TimerTick_SetPeriodSwap(uint32 swapEnable);
void   TimerTick_SetCompareSwap(uint32 swapEnable);

void   TimerTick_SetCaptureMode(uint32 triggerMode);
void   TimerTick_SetReloadMode(uint32 triggerMode);
void   TimerTick_SetStartMode(uint32 triggerMode);
void   TimerTick_SetStopMode(uint32 triggerMode);
void   TimerTick_SetCountMode(uint32 triggerMode);

void   TimerTick_SaveConfig(void);
void   TimerTick_RestoreConfig(void);
void   TimerTick_Sleep(void);
void   TimerTick_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define TimerTick_BLOCK_CONTROL_REG              (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define TimerTick_BLOCK_CONTROL_PTR              ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define TimerTick_COMMAND_REG                    (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define TimerTick_COMMAND_PTR                    ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define TimerTick_INTRRUPT_CAUSE_REG             (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define TimerTick_INTRRUPT_CAUSE_PTR             ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define TimerTick_CONTROL_REG                    (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__CTRL )
#define TimerTick_CONTROL_PTR                    ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__CTRL )
#define TimerTick_STATUS_REG                     (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__STATUS )
#define TimerTick_STATUS_PTR                     ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__STATUS )
#define TimerTick_COUNTER_REG                    (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__COUNTER )
#define TimerTick_COUNTER_PTR                    ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__COUNTER )
#define TimerTick_COMP_CAP_REG                   (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__CC )
#define TimerTick_COMP_CAP_PTR                   ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__CC )
#define TimerTick_COMP_CAP_BUF_REG               (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__CC_BUFF )
#define TimerTick_COMP_CAP_BUF_PTR               ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__CC_BUFF )
#define TimerTick_PERIOD_REG                     (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__PERIOD )
#define TimerTick_PERIOD_PTR                     ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__PERIOD )
#define TimerTick_PERIOD_BUF_REG                 (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define TimerTick_PERIOD_BUF_PTR                 ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define TimerTick_TRIG_CONTROL0_REG              (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define TimerTick_TRIG_CONTROL0_PTR              ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define TimerTick_TRIG_CONTROL1_REG              (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define TimerTick_TRIG_CONTROL1_PTR              ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define TimerTick_TRIG_CONTROL2_REG              (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define TimerTick_TRIG_CONTROL2_PTR              ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define TimerTick_INTERRUPT_REQ_REG              (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__INTR )
#define TimerTick_INTERRUPT_REQ_PTR              ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__INTR )
#define TimerTick_INTERRUPT_SET_REG              (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__INTR_SET )
#define TimerTick_INTERRUPT_SET_PTR              ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__INTR_SET )
#define TimerTick_INTERRUPT_MASK_REG             (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__INTR_MASK )
#define TimerTick_INTERRUPT_MASK_PTR             ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__INTR_MASK )
#define TimerTick_INTERRUPT_MASKED_REG           (*(reg32 *) TimerTick_cy_m0s8_tcpwm_1__INTR_MASKED )
#define TimerTick_INTERRUPT_MASKED_PTR           ( (reg32 *) TimerTick_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define TimerTick_MASK                           ((uint32)TimerTick_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define TimerTick_RELOAD_CC_SHIFT                (0u)
#define TimerTick_RELOAD_PERIOD_SHIFT            (1u)
#define TimerTick_PWM_SYNC_KILL_SHIFT            (2u)
#define TimerTick_PWM_STOP_KILL_SHIFT            (3u)
#define TimerTick_PRESCALER_SHIFT                (8u)
#define TimerTick_UPDOWN_SHIFT                   (16u)
#define TimerTick_ONESHOT_SHIFT                  (18u)
#define TimerTick_QUAD_MODE_SHIFT                (20u)
#define TimerTick_INV_OUT_SHIFT                  (20u)
#define TimerTick_INV_COMPL_OUT_SHIFT            (21u)
#define TimerTick_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define TimerTick_RELOAD_CC_MASK                 ((uint32)(TimerTick_1BIT_MASK        <<  \
                                                                            TimerTick_RELOAD_CC_SHIFT))
#define TimerTick_RELOAD_PERIOD_MASK             ((uint32)(TimerTick_1BIT_MASK        <<  \
                                                                            TimerTick_RELOAD_PERIOD_SHIFT))
#define TimerTick_PWM_SYNC_KILL_MASK             ((uint32)(TimerTick_1BIT_MASK        <<  \
                                                                            TimerTick_PWM_SYNC_KILL_SHIFT))
#define TimerTick_PWM_STOP_KILL_MASK             ((uint32)(TimerTick_1BIT_MASK        <<  \
                                                                            TimerTick_PWM_STOP_KILL_SHIFT))
#define TimerTick_PRESCALER_MASK                 ((uint32)(TimerTick_8BIT_MASK        <<  \
                                                                            TimerTick_PRESCALER_SHIFT))
#define TimerTick_UPDOWN_MASK                    ((uint32)(TimerTick_2BIT_MASK        <<  \
                                                                            TimerTick_UPDOWN_SHIFT))
#define TimerTick_ONESHOT_MASK                   ((uint32)(TimerTick_1BIT_MASK        <<  \
                                                                            TimerTick_ONESHOT_SHIFT))
#define TimerTick_QUAD_MODE_MASK                 ((uint32)(TimerTick_3BIT_MASK        <<  \
                                                                            TimerTick_QUAD_MODE_SHIFT))
#define TimerTick_INV_OUT_MASK                   ((uint32)(TimerTick_2BIT_MASK        <<  \
                                                                            TimerTick_INV_OUT_SHIFT))
#define TimerTick_MODE_MASK                      ((uint32)(TimerTick_3BIT_MASK        <<  \
                                                                            TimerTick_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define TimerTick_CAPTURE_SHIFT                  (0u)
#define TimerTick_COUNT_SHIFT                    (2u)
#define TimerTick_RELOAD_SHIFT                   (4u)
#define TimerTick_STOP_SHIFT                     (6u)
#define TimerTick_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define TimerTick_CAPTURE_MASK                   ((uint32)(TimerTick_2BIT_MASK        <<  \
                                                                  TimerTick_CAPTURE_SHIFT))
#define TimerTick_COUNT_MASK                     ((uint32)(TimerTick_2BIT_MASK        <<  \
                                                                  TimerTick_COUNT_SHIFT))
#define TimerTick_RELOAD_MASK                    ((uint32)(TimerTick_2BIT_MASK        <<  \
                                                                  TimerTick_RELOAD_SHIFT))
#define TimerTick_STOP_MASK                      ((uint32)(TimerTick_2BIT_MASK        <<  \
                                                                  TimerTick_STOP_SHIFT))
#define TimerTick_START_MASK                     ((uint32)(TimerTick_2BIT_MASK        <<  \
                                                                  TimerTick_START_SHIFT))

/* MASK */
#define TimerTick_1BIT_MASK                      ((uint32)0x01u)
#define TimerTick_2BIT_MASK                      ((uint32)0x03u)
#define TimerTick_3BIT_MASK                      ((uint32)0x07u)
#define TimerTick_6BIT_MASK                      ((uint32)0x3Fu)
#define TimerTick_8BIT_MASK                      ((uint32)0xFFu)
#define TimerTick_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define TimerTick_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define TimerTick_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(TimerTick_QUAD_ENCODING_MODES     << TimerTick_QUAD_MODE_SHIFT))       |\
         ((uint32)(TimerTick_CONFIG                  << TimerTick_MODE_SHIFT)))

#define TimerTick_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(TimerTick_PWM_STOP_EVENT          << TimerTick_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(TimerTick_PWM_OUT_INVERT          << TimerTick_INV_OUT_SHIFT))         |\
         ((uint32)(TimerTick_PWM_OUT_N_INVERT        << TimerTick_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(TimerTick_PWM_MODE                << TimerTick_MODE_SHIFT)))

#define TimerTick_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(TimerTick_PWM_RUN_MODE         << TimerTick_ONESHOT_SHIFT))
            
#define TimerTick_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(TimerTick_PWM_ALIGN            << TimerTick_UPDOWN_SHIFT))

#define TimerTick_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(TimerTick_PWM_KILL_EVENT      << TimerTick_PWM_SYNC_KILL_SHIFT))

#define TimerTick_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(TimerTick_PWM_DEAD_TIME_CYCLE  << TimerTick_PRESCALER_SHIFT))

#define TimerTick_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(TimerTick_PWM_PRESCALER        << TimerTick_PRESCALER_SHIFT))

#define TimerTick_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(TimerTick_TC_PRESCALER            << TimerTick_PRESCALER_SHIFT))       |\
         ((uint32)(TimerTick_TC_COUNTER_MODE         << TimerTick_UPDOWN_SHIFT))          |\
         ((uint32)(TimerTick_TC_RUN_MODE             << TimerTick_ONESHOT_SHIFT))         |\
         ((uint32)(TimerTick_TC_COMP_CAP_MODE        << TimerTick_MODE_SHIFT)))
        
#define TimerTick_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(TimerTick_QUAD_PHIA_SIGNAL_MODE   << TimerTick_COUNT_SHIFT))           |\
         ((uint32)(TimerTick_QUAD_INDEX_SIGNAL_MODE  << TimerTick_RELOAD_SHIFT))          |\
         ((uint32)(TimerTick_QUAD_STOP_SIGNAL_MODE   << TimerTick_STOP_SHIFT))            |\
         ((uint32)(TimerTick_QUAD_PHIB_SIGNAL_MODE   << TimerTick_START_SHIFT)))

#define TimerTick_PWM_SIGNALS_MODES                                                              \
        (((uint32)(TimerTick_PWM_SWITCH_SIGNAL_MODE  << TimerTick_CAPTURE_SHIFT))         |\
         ((uint32)(TimerTick_PWM_COUNT_SIGNAL_MODE   << TimerTick_COUNT_SHIFT))           |\
         ((uint32)(TimerTick_PWM_RELOAD_SIGNAL_MODE  << TimerTick_RELOAD_SHIFT))          |\
         ((uint32)(TimerTick_PWM_STOP_SIGNAL_MODE    << TimerTick_STOP_SHIFT))            |\
         ((uint32)(TimerTick_PWM_START_SIGNAL_MODE   << TimerTick_START_SHIFT)))

#define TimerTick_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(TimerTick_TC_CAPTURE_SIGNAL_MODE  << TimerTick_CAPTURE_SHIFT))         |\
         ((uint32)(TimerTick_TC_COUNT_SIGNAL_MODE    << TimerTick_COUNT_SHIFT))           |\
         ((uint32)(TimerTick_TC_RELOAD_SIGNAL_MODE   << TimerTick_RELOAD_SHIFT))          |\
         ((uint32)(TimerTick_TC_STOP_SIGNAL_MODE     << TimerTick_STOP_SHIFT))            |\
         ((uint32)(TimerTick_TC_START_SIGNAL_MODE    << TimerTick_START_SHIFT)))
        
#define TimerTick_TIMER_UPDOWN_CNT_USED                                                          \
                ((TimerTick__COUNT_UPDOWN0 == TimerTick_TC_COUNTER_MODE)                  ||\
                 (TimerTick__COUNT_UPDOWN1 == TimerTick_TC_COUNTER_MODE))

#define TimerTick_PWM_UPDOWN_CNT_USED                                                            \
                ((TimerTick__CENTER == TimerTick_PWM_ALIGN)                               ||\
                 (TimerTick__ASYMMETRIC == TimerTick_PWM_ALIGN))               
        
#define TimerTick_PWM_PR_INIT_VALUE              (1u)
#define TimerTick_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_TimerTick_H */

/* [] END OF FILE */
