/*******************************************************************************
* File Name: TimerTick_PM.c
* Version 2.10
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TimerTick.h"

static TimerTick_BACKUP_STRUCT TimerTick_backup;


/*******************************************************************************
* Function Name: TimerTick_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: TimerTick_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_Sleep(void)
{
    if(0u != (TimerTick_BLOCK_CONTROL_REG & TimerTick_MASK))
    {
        TimerTick_backup.enableState = 1u;
    }
    else
    {
        TimerTick_backup.enableState = 0u;
    }

    TimerTick_Stop();
    TimerTick_SaveConfig();
}


/*******************************************************************************
* Function Name: TimerTick_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: TimerTick_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerTick_Wakeup(void)
{
    TimerTick_RestoreConfig();

    if(0u != TimerTick_backup.enableState)
    {
        TimerTick_Enable();
    }
}


/* [] END OF FILE */
